#!/usr/bin/env ruby
# encoding: UTF-8

require 'net/http'
require 'rubygems'
require 'mechanize'
require 'json'

def readability_login_url
  "https://www.readability.com/readers/login/"
end

def readability_url
  "http://www.readability.com/#{@config['readability']['username']}/latest"
end

def try_to_login
  login_page = @agent.get readability_login_url
  login_page.form.username = @config["readability"]["username"]
  login_page.form.password = @config["readability"]["password"]
  login_page.form.submit
end

def send_article(article)
=begin
  @agent.post "http://www.readability.com/ajax/s/i/", {
    "stat" => "rl-article-send_to_kindle"
  }
  @agent.post "http://www.readability.com/kindle/queue", {
    "token" => "",
    "extensionType" => "bookmarklet",
    "extensionVersion" => "1",
    "fromEmbed" => "0",
    "legacyBookmarklet" => "0",
    "url" => article['url'],
    "doc" => "",
    "charset" => "UTF-8"
  }
  @agent.get "http://www.readability.com/kindle/send?article=#{article['id']}"
=end
  @agent.post "http://www.readability.com/api/kindle/v1/generator", {
    "id" => article['id'],
    "email" => @config["kindle"]["email_address"]
  }
end

def archive_article(article)
  @agent.get "http://www.readability.com/articles/#{article['id']}/ajax/archive"
end

def favorite_article(article)
  @agent.get "http://www.readability.com/articles/#{article['id']}/ajax/favorite"
end

def process_articles
  response = @agent.get readability_url
  return false if response.forms.size != 3
  doc = Nokogiri::HTML(response.body)

  articles = doc.css('ul#rdb-reading-list.bookmarks li').map do |li|
    if (li['data-article-id'])
      {"url" => li.css("div.article a.original-url").first.attributes["href"].value,
        "id" => li['data-article-id'].to_s}
    end
  end.compact!
  if articles == nil
    return "0"
  end
  articles.each do |article|
    send_article article
    #favorite_article article
    archive_article article
  end
  return articles.size.to_s
end

def main
  @config ||= JSON.parse(File.read(File.join(File.dirname(__FILE__), 'config.json')))
  @agent ||= Mechanize.new
  #@agent.user_agent = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:16.0) Gecko/20100101 Firefox/16.0"
  try_to_login
  process_articles
end

puts "#{main} article(s) processed."
